import importlib
import os

original_settings = os.environ.get('RIGHTHOOK_ORIGINAL_DJANGO_SETTINGS_MODULE')
original_settings_module = importlib.import_module(original_settings)
globals().update(original_settings_module.__dict__)

ROOT_URLCONF = 'righthook.urls'
WSGI_APPLICATION = 'righthook.wsgi.application'



from django.conf import settings

RIGHTHOOK_BASE_URL = getattr(settings, 'RIGHTHOOK_BASE_URL', 'webhooks')
RIGHTHOOK_REQUEST_PARAMS = getattr(settings, 'RIGHTHOOK_REQUEST_PARAMS', {
    'GET', 
    'POST', 
    'META.SERVER_NAME',
    'META.HTTP_HOST',
    'META.REQUEST_METHOD',
    'META.CONTENT_TYPE',
    'META.REMOTE_HOST',
    'META.REMOTE_ADDR',
    'META.TZ',
    })

RIGHTHOOK_MAX_BODY_SIZE = getattr(settings, 'RIGHTHOOK_MAX_BODY_SIZE', 1024)



#!/usr/bin/env python
import os
import sys

if __name__ == "__main__":
    os.environ["RIGHTHOOK_ORIGINAL_DJANGO_SETTINGS_MODULE"] =  os.environ['DJANGO_SETTINGS_MODULE']
    os.environ["DJANGO_SETTINGS_MODULE"] = "righthook.settings"

    from django.core.management import execute_from_command_line

    execute_from_command_line(sys.argv)



from django import http
from righthook import appsettings, tasks


def receive_hook(request):
    tasks.process_hook.delay(request.path, serialize_request(request))
    return http.HttpResponse(200)


def serialize_request(request):
    r = {}
    for key in appsettings.RIGHTHOOK_REQUEST_PARAMS:
        r[key] = access_key(request, key)
    return r


def access_key(root, key, sep='.', default=None):
    '''
    Look up a key in a potentially nested object `root` by its `sep`-separated
    path. Returns `default` if the key is not found.

    Example:
        access_key({'foo': {'bar': 1}}, 'foo.bar') -> 1
    '''
    props = key.split('.')
    props.reverse()
    while props and root:
        prop = props.pop()
        root = access(root, prop, default=default)
    return root


def access(obj, prop, default=None):
    try:
        return getattr(obj, prop)
    except AttributeError as e:
        pass

    try:
        return obj[prop]
    except (KeyError, TypeError) as e:
        pass

    return default



import os

os.environ['RIGHTHOOK_ORIGINAL_DJANGO_SETTINGS_MODULE'] = os.environ['DJANGO_SETTINGS_MODULE']
os.environ['DJANGO_SETTINGS_MODULE'] = "righthook.settings"

from django.core.wsgi import get_wsgi_application
application = get_wsgi_application()



from celery import task
from righthook import signals


@task(ignore_result=True)
def process_hook(path, request_data):
    signals.webhook_received.send_robust(path, path=path, request_data=request_data)



#!/usr/bin/python

import setuptools

setuptools.setup(
    name='righthook',
    version='0.0.1',
    packages = setuptools.find_packages(exclude=[]),
    author = 'David Hughes',
    author_email = 'd@vidhughes.com',
    url = 'https://github.com/davehughes/righthook',
    download_url = 'https://github.com/davehughes/righthook/tarball/0.0.1',
    keywords = [
        'Django', 'Celery', 'task', 'queue', 'webhook',
        ],
    install_requires = [
        'django-celery>=3.0',
        ],
    )


